==> apache-inlong-1.9.0-src.tar.gz: apache-inlong-1.9.0/inlong-sort/sort-common/src/test/java/org/apache/inlong/sort/protocol/transformation/WatermarkFieldTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.sort.protocol.transformation;

import org.apache.inlong.sort.formats.common.TimestampFormatInfo;
import org.apache.inlong.sort.protocol.FieldInfo;
import org.apache.inlong.sort.protocol.transformation.TimeUnitConstantParam.TimeUnit;

/**
 * Test for {@link WatermarkField}
 */
public class WatermarkFieldTest extends FunctionBaseTest {

    @Override
    public Function getTestObject() {
        return new WatermarkField(new FieldInfo("ts", new TimestampFormatInfo()),
                new StringConstantParam("10"), new TimeUnitConstantParam(TimeUnit.HOUR));
    }

    @Override
    public String getExpectFormat() {
        return "WATERMARK FOR `ts` AS `ts` - INTERVAL '10' HOUR";
    }
}

==> apache-inlong-2.3.0-src.tar.gz: apache-inlong-2.3.0/inlong-sort/sort-common/src/test/java/org/apache/inlong/sort/protocol/transformation/WatermarkFieldTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.sort.protocol.transformation;

import org.apache.inlong.common.pojo.sort.dataflow.field.format.TimestampFormatInfo;
import org.apache.inlong.sort.protocol.FieldInfo;
import org.apache.inlong.sort.protocol.transformation.TimeUnitConstantParam.TimeUnit;

/**
 * Test for {@link WatermarkField}
 */
public class WatermarkFieldTest extends FunctionBaseTest {

    @Override
    public Function getTestObject() {
        return new WatermarkField(new FieldInfo("ts", new TimestampFormatInfo()),
                new StringConstantParam("10"), new TimeUnitConstantParam(TimeUnit.HOUR));
    }

    @Override
    public String getExpectFormat() {
        return "WATERMARK FOR `ts` AS `ts` - INTERVAL '10' HOUR";
    }
}
